/*
 *  Searching/Queries/Content.cs
 *  Copyright (C) 2006-2007 Marcin Krystian Krzywonos
 *  License: GNU/GPL version 2
 */


using System;
using System.Collections;
using Mono.Unix;
using System.Xml;
using Incollector.Engine;
using Incollector.GUI.Widgets;


namespace Incollector.Searching.Queries {
	
	public class Content : Incollector.Searching.Query {
		
		protected Gtk.Entry    content;
		protected Gtk.Widget   widget;
		protected Gtk.ComboBox conditionals;
		
		public enum ConditionalEnum {
			Contain    = 0,
			NotContain = 1
		}
		
		protected ConditionalEnum Conditional {
			get { return (ConditionalEnum) conditionals.Active; }
			set { conditionals.Active = (int) value; }
		}
		
		protected string ContentValue {
			get { return this.content.Text;  }
			set { this.content.Text = value; }
		}
		
		public override Gtk.Widget QueryWidget {
			get { return widget; }
		}
		
		public override string ID {
			get { return "content"; }
		}
		
		public override string Name {
			get { return Catalog.GetString ("Content"); }
		}
		
		
		public Content ()
		{
			widget = new Gtk.HBox ();
			(widget as Gtk.HBox).Spacing = 6;
			
			conditionals = new Gtk.ComboBox (new string [] {
								Catalog.GetString ("contains"),
								Catalog.GetString ("doesn't contain")
							});
			conditionals.Active = 0;
			(widget as Gtk.HBox).PackStart (conditionals, true, true, 0);
			
			content = new Gtk.Entry ();
			(widget as Gtk.HBox).PackEnd (content, true, true, 0);
			
			widget.ShowAll ();
		}
		
		
		public override Query New ()
		{
			return (Query) new Content ();
		}
		
		
		public override Query Clone ()
		{
			Content query = new Content ();
			query.Conditional  = this.Conditional;
			query.ContentValue = this.ContentValue.Clone () as string;
			
			return query;
		}
		
		
		public override bool CheckQuery (Engine.Entry entry)
		{	
			if (this.Conditional == ConditionalEnum.Contain)
				return entry.Data.Search (this.ContentValue);
			else
				return !entry.Data.Search (this.ContentValue);
		}
		
		
		public override Query ReadXml (XmlTextReader reader)
		{
			Content query = new Content ();
			
			try {
				query.Conditional = (ConditionalEnum) System.Enum.Parse (typeof (ConditionalEnum), reader.GetAttribute ("conditional"));
			} catch {}
			
			query.ContentValue = Text.PrepareText2 (reader.GetAttribute ("content"));
			
			return query;
		}
		
		
		public override void WriteXml (XmlTextWriter writer)
		{
			writer.WriteStartElement (this.ID);
				writer.WriteAttributeString ("conditional", Conditional.ToString ());
				writer.WriteAttributeString ("content", Text.PrepareText (this.ContentValue));
			writer.WriteEndElement ();
		}
	}
}
